#
# spec file for package ddrescueview
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           ddrescueview
Version:        0.4.5
Release:        3.5
Summary:        Graphical viewer for GNU ddrescue mapfiles
License:        GPL-3.0-only
Group:          Productivity/Archiving/Backup
URL:            https://sourceforge.net/projects/ddrescueview/
Source:         https://sourceforge.net/projects/ddrescueview/files/Test%20builds/v%{version}/ddrescueview-source-%{version}.tar.xz/download#/%{name}-%{version}.tar.xz
BuildRequires:  gtk2-devel
BuildRequires:  lazarus-ide
BuildRequires:  lazarus-lcl-qt5
BuildRequires:  lazarus-tools
BuildRequires:  libQt5Pas-devel
BuildRequires:  update-desktop-files

%description
This small tool allows the user to graphically examine ddrescue's map files in a user friendly GUI application. The Main window displays a block grid with each block's color representing the block types it contains. Many people know this type of view from defragmentation programs.

%prep
%setup -q -n %name-source-%version
chmod -x *.txt

%build
lazbuild \
	--lazarusdir=%{_libdir}/lazarus \
%ifarch x86_64
	--cpu=x86_64 \
%endif
	--widgetset=qt5 \
	-B source/ddrescueview.lpi \
	&& [ -f source/ddrescueview ]
sed -i 's/\r//' *.txt

%install
install -Dm 755 source/ddrescueview %{buildroot}%{_bindir}/%{name}
install -Dm 644 resources/linux/man/man1/ddrescueview.1 %{buildroot}%{_mandir}/man1/%{name}.1
cp -r resources/linux/icons/ %{buildroot}%{_datadir}/
install -Dm 644 resources/linux/applications/%{name}.desktop %{buildroot}%{_datadir}/applications/%{name}.desktop
%suse_update_desktop_file %{name}

%files
%license gpl.txt
%doc readme.txt changelog.txt
%{_mandir}/man1/%{name}.1%{?ext_man}
%{_bindir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/

%changelog
* Thu Feb  1 2024 PragmaticLinux <info@pragmaticlinux.com>
- Fixed build error with Lazarus 3.0 (boo#1219436).
* Sun Sep  3 2023 Sebastian Wagner <sebix@sebix.at>
- Replace build requirement 'lazarus' by 'lazarus-tools' and 'lazarus-lcl-qt5'
  The package 'lazarus' was spilt into multiple sub-packages
* Mon May  9 2022 Paolo Stivanin <info@paolostivanin.com>
- Update to v0.4.5:
  * Fixed an issue that emerged with the mapfile backup mechanism
    in ddrescue 1.24 and later.
  * When an update interval was set in ddrescueview, the program
    would be stuck on the backup version of the mapfile, causing
    no progress to be shown over time. With this patch, ddrescueview
    avoids the issue by re-opening the file every time it needs to be read.
  * Abandoned the nonsensical versioning scheme (alpha x - labled versions)
* Sat Sep  5 2020 Sebastian Wagner <sebix+novell.com@sebix.at>
- remove use-getters-for-fields-in-other-classes.patch, integrated upstream.
- remove pie.patch, setting -fPIE does not work anymore.
- remove ddrescueview.desktop, upstream has a desktop file.
- update to version 0.4 apha 4:
  - Updated to compile on FPC 3.2.0 without errors. Thanks to Peter Green for the patch.
  - It's now possible to select a range on the Zoom Bar using right click dragging, just like on the Block Grid.
  - Added an option in the Settings to zoom in on mouse position without centering the Block Grid on that position.
    This is now the default. It seems more intuitive when the blocks previously under the mouse
    stay under the mouse after zooming in or out.
  - Added an Option 'Center on Current Position' to the View menu, which keeps the Block Grid centered on the
    current rescue position. Handy to keep the rescue position on screen when zoomed in.
    This overrides much of the usual zooming functionality and deactivates interaction with the Zoom Bar.
  - Zooming and scrolling in large map files is now considerably faster.
  - Application title (as reported to the OS, for the task bar etc.) now shows loaded file name.
  - The program will now make a second attempt to refresh the mapfile, when ddrescue is currently rewriting it.
  - New application icon in multiple sizes up to 256x256
  - Reduced compiler warnings and hints
* Sat Aug 29 2020 Sebastian Wagner <sebix+novell.com@sebix.at>
- add use-getters-for-fields-in-other-classes.patch to fix build
- add pie.patch to use PIE for linking
- run spec-cleaner
* Sun Feb  4 2018 sebix+novell.com@sebix.at
- specfile:
  * use sed instead of dos2unix
  * use %%setup's -c flag to deal with the source tarball structure
* Sat Feb  3 2018 sebix+novell.com@sebix.at
- initial package for version 0.4~alpha3
